@@ -1,6 +1,6 @@
 /***************************************************************************
     Copyright 2014 Andreas Xavier
-    Copyright 2014 Inge Wallin
+    Copyright 2014 Inge Wallin <inge@lysator.liu.se>
  ***************************************************************************/
 
 /***************************************************************************
@@ -23,12 +23,13 @@
 #include <klocalizedstring.h>
 
 // Qt
-#include <QtGui>
+#include <QPainter>
+#include <QPen>
 #include <QColor>
-#include <QtWidgets/QPushButton>
-#include <QtWidgets/QGraphicsDropShadowEffect>
-#include <QtWidgets/QVBoxLayout>
-#include <QtWidgets/QLabel>
+#include <QPushButton>
+#include <QGraphicsDropShadowEffect>
+#include <QVBoxLayout>
+#include <QLabel>
 
 // Parley
 #include "utils.h"
