@@ -46,7 +46,7 @@ public:
         EntryColumnsMAX
     };
 
-    VocabularyDelegate(QObject *parent = 0);
+    explicit VocabularyDelegate(QObject *parent = 0);
 
     QWidget * createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
 
