@@ -14,8 +14,8 @@
 #ifndef PRACTICE_AUDIOBUTTON_H
 #define PRACTICE_AUDIOBUTTON_H
 
-#include <QtWidgets/QToolButton>
-#include <QtMultimedia/QMediaPlayer>
+#include <QToolButton>
+#include <QMediaPlayer>
 #include <QUrl>
 
 class QMediaPlayer;
@@ -27,7 +27,7 @@ class AudioButton : public QToolButton
 {
     Q_OBJECT
 public:
-    AudioButton(QWidget *parent);
+    explicit AudioButton(QWidget *parent);
     void setSoundFile(QUrl url);
 
 private Q_SLOTS:
